<?php

namespace App\Http\Controllers;

use App\Models\Departamento;
use App\Models\Empleado;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Arr;

class DepartamentoController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        //
        $datos['departamentos'] = Departamento::paginate(5);
        return view('departamento.index', $datos); 
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
        return view('departamento.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //
        $campos=[
            'dpto_name'=>'required|string|max:100',
        ];

        $mensaje=[
            'required'=>'El campo :attribute es requerido',
        ];

    $this->validate($request, $campos, $mensaje);

    //
    $datosDepartamento = request()->except('_token');
    
    Departamento::insert($datosDepartamento);

    return redirect('departamento')->with('mensaje', 'Departamento agregado exitosamente');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show(Departamento $departamento)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
        $departamento=Departamento::FindOrFail($id);
        return view('departamento.edit', compact('departamento') );
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //
        $campos=[
            'dpto_name'=>'required|string|max:100',
        ];

    $mensaje=[
        'required'=>'El campo :attribute es requerido',
    ];

    $this->validate($request, $campos, $mensaje);

        //
        $datosDepartamento = request()->except(['_token', '_method']);
        
        Departamento::where('id', '=', $id)->update($datosDepartamento);
        $departamento=Departamento::FindOrFail($id);
        //return view('empleado.edit', compact('empleado') );
        return redirect('departamento')->with('mensaje', 'Departamento modificado');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response;
     */
    public function destroy($id)
    {
        //
        $empleados = Empleado::where('departamentos_id', $id)->get();
        if(count($empleados) >= 1) {
            //return view('departamento.reasignar', compact('empleados', 'departamentos', 'id', 'mensaje2') );
            return redirect()->route('departamento.reasignarShow',[$id]);
        }
        else {
            Departamento::destroy($id);
            return redirect('departamento')->with('mensaje', 'Departamento borrado');

        }
    }

    /**
     * Update the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response;
     */
    public function reasignarShow(Request $request, $id)
    {
        $departamento=Departamento::FindOrFail($id);
        $departamentos = Departamento::where('id','!=',$id)->get();
        $empleados = Empleado::where('departamentos_id', $departamento->id)->get();
        $mensaje2 = 'Este departamento tiene usuarios asignados! - Reasigne los siguientes usuarios antes de borrar el departamento.';
        
        return view('departamento.reasignar', compact('empleados', 'departamentos', 'id', 'mensaje2') );
    }


    // actualiza el departamento de los empleados seleccionados

    public function reasignar(Request $request, $id)
    {
        //validate select input
        
        //dd($request);

        $validar = request()->except(['_token', '_method']);
         $campos=[
            'empleado.*.dep'=>'required',
        ];

        $mensaje=[
            'required'=>'Usted debe seleccionar un departamento para cada usuario.',
        ];

        $validator = Validator::make($validar, $campos, $mensaje);
        if ($validator->fails()) {
            return redirect()->back()
                 ->withErrors($validator)
                 ->withInput();
      } 

        
        $departamento = Departamento::find($id);
        $empleados = request()->except(['_token', '_method']);
        $emp_id = Arr::pluck($empleados, '*.emp');
        $emp_id = Arr::flatten($emp_id);
        $dep_id = Arr::pluck($empleados, '*.dep');
        $dep_id = Arr::flatten($dep_id);
        $datos = array_combine($emp_id, $dep_id);
        //dd($datos);

        foreach($datos as $key => $value){
            Empleado::where('id', $key)->update(['departamentos_id'=>$value]);
        }
                
        return redirect('departamento')->with('mensaje', 'Empleados actualizados exitosamente. Ahora puede borrar el departamento '.$departamento->dpto_name );

 
    }
}
