<?php

namespace App\Http\Controllers;

use App\Models\Empleado;
use App\Models\Departamento;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Storage;

class EmpleadoController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $empleados = Empleado::leftJoin('departamentos', 'departamentos.id', '=', 'empleados.departamentos_id')
        ->select('empleados.id', 'empleados.Nombre', 'empleados.ApellidoMaterno', 'empleados.ApellidoPaterno', 'empleados.Correo', 'empleados.Foto', 'departamentos.dpto_name')
        ->get();
        //$datos['empleados'] = Empleado::paginate(5);
        //$empleado = Empleado::with('dpto')->get();
        //$departamentos = Departamento::all();
        //$empleados = Departamento::where('id', $empleado->departamentos_id)->pluck('dpto_name')->first();
        return view('empleado.index', compact('empleados') );
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
        public function create()
        {
            $datos['departamentos'] = Departamento::get();
            return view('empleado.create', $datos);
        }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {

        $campos=[
            'Nombre'=>'required|string|max:100',
            'ApellidoPaterno'=>'required|string|max:100',
            'ApellidoMaterno'=>'required|string|max:100',
            'Correo'=>'required|email',
            'departamentos_id'=>'required|string|max:100',
            'Foto'=>'required|max:10000|mimes:jpg,png,jpeg',
        ];

    $mensaje=[
        'required'=>'El campo :attribute es requerido',
        'Foto.required'=>'La foto es requerida',
    ];

    $this->validate($request, $campos, $mensaje);

        //$datosEmpleado = request()->all();
        $datosEmpleado = request()->except('_token');

        if ($request->hasFile('Foto')) {
            $datosEmpleado['Foto'] = $request->file('Foto')->store('uploads','public');
        }
        Empleado::insert($datosEmpleado);
        //return response()->json($datosEmpleado);
        return redirect('empleado')->with('mensaje', 'Empleado agregado exitosamente');

    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\Empleado  $empleado
     * @return \Illuminate\Http\Response
     */
    public function show(Empleado $empleado)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\Empleado  $empleado
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
        $empleado=Empleado::FindOrFail($id);
        $datos['departamentos'] = Departamento::get();
        return view('empleado.edit', compact('empleado'), $datos );
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\Empleado  $empleado
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $campos=[
            'Nombre'=>'required|string|max:100',
            'ApellidoPaterno'=>'required|string|max:100',
            'ApellidoMaterno'=>'required|string|max:100',
            'Correo'=>'required|email',
            'departamentos_id',
        ];

    $mensaje=[
        'required'=>'El :attribute es requerido',
    ];

    if ($request->hasFile('Foto')) {
        $campos=['Foto'=>'required|max:10000|mimes:jpg,png,jpeg',];
        $mensaje=[
            'Foto.required'=>'La foto es requerida',
        ];
    }

    $this->validate($request, $campos, $mensaje);

        //
        $datosEmpleado = request()->except(['_token', '_method']);

        if ($request->hasFile('Foto')) {
            $empleado=Empleado::FindOrFail($id);
            Storage::delete('public/'.$empleado->Foto);
            $datosEmpleado['Foto'] = $request->file('Foto')->store('uploads','public');
        }
        
        Empleado::where('id', '=', $id)->update($datosEmpleado);
        $empleado=Empleado::FindOrFail($id);
        //return view('empleado.edit', compact('empleado') );
        return redirect('empleado')->with('mensaje', 'Empleado modificado');

    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\Empleado  $empleado
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
        $empleado=Empleado::FindOrFail($id);
        if(Storage::delete('public/'.$empleado->Foto)) {
            Empleado::destroy($id);
        }
        
        return redirect('empleado')->with('mensaje', 'Empleado borrado');
    }
}
