<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Empleado;
use App\Models\Departamento;
use PDF;    

class ReporteController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        
        $datos['departamentos'] = Departamento::get();
        return view('reporte.index', $datos );
    }

    /**
     * Display the report.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */

    public function generar(Request $request)
    {
     
        //BUSQUEDA POR DEPARTAMENTOS
        if ($request->has('reporte_id') && $request->reporte_id != 0)
            {
                
                $departamento=Departamento::FindOrFail($request->reporte_id);        
                $empleados = Empleado::where('departamentos_id', $departamento->id)
                ->select('empleados.id', 'empleados.Nombre', 'empleados.ApellidoMaterno', 'empleados.ApellidoPaterno', 'empleados.Correo')
                ->get();

                if(count($empleados) == 0) {
                    return redirect('reporte')->with('mensaje', 'Este departamento no tiene usuarios asignados!');
                }
                else
                {
                    if($request->has('download'))
                    {

                        $pdf = PDF::loadView('reporte.pdfexp', compact('departamento', 'empleados'));
                        return $pdf->download('reporte.pdf');
                    }
                  
                return view('reporte.generar', compact('empleados', 'departamento') );
                }

            }
        //END BUSQUEDA POR DEPARTAMENTOS

        //BUSQUEDA POR USUARIO
        elseif ($request->has('buscar')) 
        {

        // Validación de campos

        $campos=[
            'buscar'=>'required',
            'cols'=>'required',
        ];

        $mensaje=[
            'buscar.required'=>'Introduzca un valor en el campo de búsqueda',
            'cols.required'=>'Seleccione una opción para la búsqueda',
            'required'=>'El :attribute es requerido',
        ];   

        $this->validate($request, $campos, $mensaje);

        $query = $request->input( 'buscar' );
        $cols = $request->get('cols'); 
            
        // busqueda en toda la tabla Empleados
            if (  !empty($cols) && in_array('Todos', $cols) ) {
                $empleados = Empleado::where('Nombre','LIKE','%'.$query.'%')
                ->orWhere('id','LIKE','%'.$query.'%')
                ->orWhere('ApellidoPaterno','LIKE','%'.$query.'%')
                ->orWhere('ApellidoMaterno','LIKE','%'.$query.'%')
                ->orWhere('Correo','LIKE','%'.$query.'%')
                ->get();

                $q_string = 'cols[]='.$cols[0];

                if(count($empleados) == 0) {
                    return redirect('reporte')->with('mensaje', 'No se encontraron resultados. Intente una nueva búsqueda!');
                }
                else
                {
                    if($request->has('download'))
                    {
                        $pdf = PDF::loadView('reporte.pdfexp', compact('query', 'empleados'));
                        return $pdf->download('reporte.pdf');
                    }
                  
                return view('reporte.generar', compact('empleados', 'query', 'q_string') );
                }
                
            }
            
        // busqueda en los campos seleccionados de la tabla Empleados
            if ( !empty($cols) && !in_array('Todos', $cols) ) {
                $empleados = Empleado::where($cols[0],'LIKE','%'.$query.'%');
                    foreach($cols as $col) {
                        $empleados->orWhere($col,'LIKE','%'.$query.'%');
                        $q_str[] = 'cols[]='.$col;
                    }
                $empleados = $empleados->get();
                $q_string = implode("&", $q_str);

                if(count($empleados) == 0) {
                    return redirect('reporte')->with('mensaje', 'No se encontraron resultados. Intente una nueva búsqueda!');
                }
                else
                {
                    if($request->has('download'))
                    {
                        $pdf = PDF::loadView('reporte.pdfexp', compact('query', 'empleados'));
                        return $pdf->download('reporte.pdf');
                    }
                 
                return view('reporte.generar', compact('empleados', 'query', 'q_string') );
                }  
            }

           
           
        }
    }


}